package com.yyb.controller;

import com.alibaba.druid.util.StringUtils;
import com.yyb.commons.utils.Page;
import com.yyb.pojo.BaseDict;
import com.yyb.pojo.Customer;
import com.yyb.pojo.QueryVo;
import com.yyb.service.BaseDictService;
import com.yyb.service.CustomerService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;

import java.util.List;

@Controller
@RequestMapping("customer")
public class CustomerController {
    // 客户来源
    @Value("${CUSTOMER_FROM_TYPE}")
    private String CUSTOMER_FROM_TYPE;
    // 客户行业
    @Value("${CUSTOMER_INDUSTRY_TYPE}")
    private String CUSTOMER_INDUSTRY_TYPE;
    // 客户级别
    @Value("${CUSTOMER_LEVEL_TYPE}")
    private String CUSTOMER_LEVEL_TYPE;
    @Autowired
    private BaseDictService baseDictService;

    @Autowired
    private CustomerService customerService;
    /**
     * 显示客户列表
     *
     * @return
     */
    @RequestMapping("list")
    public String queryCustomerList(QueryVo queryVo, Model model) {
        // 客户来源
        List<BaseDict> fromType = baseDictService.queryBaseDictByDictTypeCode(CUSTOMER_FROM_TYPE);
        // 所属行业
        List<BaseDict> industryType = baseDictService.queryBaseDictByDictTypeCode(CUSTOMER_INDUSTRY_TYPE);
        // 客户级别
        List<BaseDict> levelType = baseDictService.queryBaseDictByDictTypeCode(CUSTOMER_LEVEL_TYPE);

        try {
            // 解决get请求乱码问题
            if (!StringUtils.isEmpty(queryVo.getCustName())) {
                queryVo.setCustName(new String(queryVo.getCustName().getBytes("ISO-8859-1"), "UTF-8"));
            }
        } catch (Exception e) {
            e.printStackTrace();
        }
        // 把前端页面需要显示的数据放到模型中
        model.addAttribute("fromType", fromType);
        model.addAttribute("industryType", industryType);
        model.addAttribute("levelType", levelType);

        // 分页查询数据
        Page<Customer> page = this.customerService.queryCustomerByQueryVo(queryVo);
        // 把分页查询的结果放到模型中
        model.addAttribute("page", page);

        // 数据回显
        model.addAttribute("custName", queryVo.getCustName());
        model.addAttribute("custSource", queryVo.getCustSource());
        model.addAttribute("custIndustry", queryVo.getCustIndustry());
        model.addAttribute("custLevel", queryVo.getCustLevel());

        return "customer";
    }

    /**
     * 根据id查询用户,返回json格式数据
     *
     * @param id
     * @return
     */
    @RequestMapping("edit")
    @ResponseBody
    public Customer queryCustomerById(Long id) {
        Customer customer = this.customerService.queryCustomerById(id);
        return customer;
    }

    /**
     * 根据id查询用户,返回更新后客户的json格式数据
     *
     * @param id
     * @return
     */
    @RequestMapping("update")
    @ResponseBody
    public String updateCustomerById(Customer customer) {
        int result = this.customerService.updateCustomerById(customer);
        return "OK";
    }

    /**
     * 删除用户
     *
     * @param id
     * @return
     */
    @RequestMapping("delete")
    @ResponseBody
    public String deleteCustomerById(Long id) {
      int result=  this.customerService.deleteCustomerById(id);
        return "ok";
    }
}
